## cdist-type__dog_vdi(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__dog_vdi - Manage Sheepdog VM images

## 2. DESCRIPTION

The dog program is used to create images for sheepdog to be used in qemu.

## 3. OPTIONAL PARAMETERS

state
  Either "present" or "absent", defaults to "present"
size

  Size of the image in "dog vdi" compatible units.

      Required if state is "present".

## 4. EXAMPLES

    # Create a 50G size image
    __dog_vdi nico-privat.sky.ungleich.ch --size 50G

    # Create a 50G size image (more explicit)
    __dog_vdi nico-privat.sky.ungleich.ch --size 50G --state present

    # Remove image
    __dog_vdi nico-privat.sky.ungleich.ch --state absent

    # Remove image - keeping --size is ok
    __dog_vdi nico-privat.sky.ungleich.ch --size 50G --state absent

## 5. SEE ALSO

- cdist-type(7)
- dog(8)
- qemu(1)

## 6. COPYING

Copyright (C) 2014 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).